@@ -18,7 +18,7 @@
 
 namespace panda { namespace backtrace {
 
-static iptr<BacktraceInfo> dl_produce(const RawTrace& buffer);
+static StackframePtr dl_produce(const void*);
 static BacktraceProducer dl_producer(dl_produce);
 
 static DwarfInfoMap load_dwarf_info(const SharedObjectMap& so_map) {
@@ -51,24 +51,18 @@ static DwarfInfoMap load_dwarf_info(const SharedObjectMap& so_map) {
 }
 
 
-iptr<BacktraceInfo> dl_produce(const RawTrace& buffer) {
+StackframePtr dl_produce(const void* frame_ptr) {
     SharedObjectMap so_map;
     std::vector<StackframePtr> frames;
     gather_info(so_map);
     auto map = load_dwarf_info(so_map);
-    for(void* ip_raw: buffer) {
-        auto ip_addr = reinterpret_cast<std::uint64_t>(ip_raw);
-        for(auto& it: map) {
-            //std::cout << "resolving " << it.first << "\n";
-            auto frame = it.second->resolve(ip_addr);
-            if (frame) {
-                frames.emplace_back(std::move(frame));
-                break;
-            }
-        }
+    auto ip_addr = reinterpret_cast<std::uint64_t>(frame_ptr);
+    for(auto& it: map) {
+        //std::cout << "resolving " << it.first << "\n";
+        auto frame = it.second->resolve(ip_addr);
+        if (frame) return frame;
     }
-    auto ptr = new BacktraceInfo(std::move(frames));
-    return iptr<BacktraceInfo>(ptr);
+    return StackframePtr();
 }
 
 void install_backtracer() {
